Stan Math Library: stan/math/prim/mat/meta/length_mvt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

length_mvt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_LENGTH_MVT_HPP
2 #define STAN_MATH_PRIM_MAT_META_LENGTH_MVT_HPP
3
4 #include <stan/math/prim/scal/meta/length_mvt.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stdexcept>
7 #include <vector>
8
9 namespace stan {
10
11 template <typename T, int R, int C>
12 size_t length_mvt(const Eigen::Matrix<T, R, C>& ) {
13 return 1U;
14 }
15
16 template <typename T, int R, int C>
17 size_t length_mvt(const std::vector<Eigen::Matrix<T, R, C> >& x) {
18 return x.size();
19 }
20
21 }
22 #endif
23
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp
length_mvt.hpp
stan::length_mvt
size_t length_mvt(const Eigen::Matrix< T, R, C > &)
Definition: length_mvt.hpp:12

[ Stan Home Page ] © 2011–2016, Stan Development Team.